#[repr(u8)]pub enum Etheren {
ZERO = 0,
ONE = 1,
}Variants
ZERO = 0
Reception immediately stops and transmission stops after a bad CRC is appended to any currently transmitted frame.
ONE = 1
MAC is enabled, and reception and transmission are possible.
Implementations