#[repr(u8)]pub enum Offrst {
ZERO = 0,
ONE = 1,
}Variants
ZERO = 0
The timer is not affected and no action occurs, besides clearing OFFEN, when the offset is reached.
ONE = 1
If OFFEN is set, the timer resets to zero when the offset setting is reached. The offset event does not cause a timer interrupt.
Implementations